@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0016';
+our $VERSION = '0.0017';
 
 use Moo;
 use strictures 2;
@@ -14,8 +14,7 @@ use namespace::clean;
 
 
 has model => (
-  is       => 'rw',
-  required => 1,
+  is => 'rw',
 );
 
 
@@ -43,6 +42,7 @@ has verbose => (
 
 sub BUILD {
   my ($self, $args) = @_;
+  return unless $args->{model};
   # sanitize the model name
   (my $model = $args->{model}) =~ s/\W/_/g;
   $self->model(lc $model);
@@ -50,7 +50,11 @@ sub BUILD {
   $self->_sqlite->query(
     'create table if not exists '
     . $self->model
-    . ' (id integer primary key autoincrement, settings json not null, name text not null)'
+    . ' (
+        id integer primary key autoincrement,
+        settings json not null,
+        name text not null
+      )'
   );
 }
 
@@ -190,7 +194,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0016
+version 0.0017
 
 =head1 SYNOPSIS
 
@@ -234,7 +238,7 @@ settings in an SQLite database. It is a "librarian", if you will.
 
   $model = $synth->model;
 
-The B<required> model name of the synthesizer.
+The model name of the synthesizer.
 
 This is turned into lowercase and all non-alpha-num characters are
 converted to an underline character (C<_>).
